==> gbook-0.14.tar.bz2: gbook/gbook.i18n-es.php <==

<?php

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2005-2006 Tino Reichardt
 * Copyright (C) 2012 Manuel Blasco Felip
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "Nombre",
'f_origin'        => "Desde",
'f_ip'            => "IP",
'f_browser'       => "Navegador",
'f_email'         => "email",
'f_homepage'      => "Pagina web",
'f_captcha'       => "Codigo",
'f_entry'         => "mensaje",
'f_ip'            => "IP",
'f_browser'       => "Navegador",

# buttons
'b_submit'        => "Enviar",
'b_reply'         => "Contestar",
'b_change'        => "Modificar",
'b_delete'        => "Borrar",
'b_reset'         => "Limpiar",

# misc
'headline'        => "Libro de visitas",
'hl_create'       => "Dejar un nuevo mensaje:",
'hl_modify'       => "Modificar un mensaje:",
'new_entry'       => "Bienvenidos al libro de visitas.  [{{fullurl:$this->myAddPage|action=add}} '''Pulse aqui'''] para dejar su mensaje.",
'entry_okay'      => "Gracias por dejar su mensaje ;)",
'delete_okay'     => "Su mensaje ha sido borrado.",
'change_okay'     => "Su mensaje ha sido modificado.",
'show_entries'    => "Mostrar mensajes.",
'captcha_desc'    => "Por favor, teclee las letras y numeros que vea en la imagen.",
'captcha_fail'    => "Lo sentimos, el codigo introducido es erroneo.",
'err_name'        => "Su nombre es obligatorio.",
'err_entry'       => "No puede dejar un mensaje en blanco.",
'err_noentry'     => "Lo sentimos, el mensaje no existe.",
'err_captcha'     => "El codigo esta en blanco."
);

?>

==> gbook-0.17.tar.bz2: gbook/gbook.i18n-es.php <==
<?php

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2005-2006 Tino Reichardt
 * Copyright (C) 2012 Manuel Blasco Felip
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "Nombre",
'f_origin'        => "Desde",
'f_ip'            => "IP",
'f_browser'       => "Navegador",
'f_email'         => "email",
'f_homepage'      => "Pagina web",
'f_captcha'       => "Codigo",
'f_entry'         => "mensaje",
'f_ip'            => "IP",
'f_browser'       => "Navegador",

# buttons
'b_submit'        => "Enviar",
'b_reply'         => "Contestar",
'b_change'        => "Modificar",
'b_delete'        => "Borrar",
'b_reset'         => "Limpiar",

# misc
'headline'        => "Libro de visitas",
'hl_create'       => "Dejar un nuevo mensaje:",
'hl_modify'       => "Modificar un mensaje:",
'new_entry'       => "Bienvenidos al libro de visitas.  [{{fullurl:$this->myAddPage|action=add}} '''Pulse aqui'''] para dejar su mensaje.",
'entry_okay'      => "Gracias por dejar su mensaje ;)",
'delete_okay'     => "Su mensaje ha sido borrado.",
'change_okay'     => "Su mensaje ha sido modificado.",
'show_entries'    => "Mostrar mensajes.",
'captcha_desc'    => "Por favor, teclee las letras y numeros que vea en la imagen.",
'captcha_fail'    => "Lo sentimos, el codigo introducido es erroneo.",

# error
'err_name'        => "Su nombre es obligatorio.",
'err_entry'       => "No puede dejar un mensaje en blanco.",
'err_noentry'     => "Lo sentimos, el mensaje no existe.",
'err_captcha'     => "El codigo esta en blanco.",
'err_blocked'     => "Lo sentimos, no tiene permiso para publicar en este libro de visitas.",
'err_spam'        => "Lo sentimos, no está permitido el spam."
);

?>
